==> scala-guice_2.12-4.1.0-sources.jar: net/codingwell/scalaguice/BindingExtensions.scala <==
/*
 *  Copyright 2010-2014 Benjamin Lings
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.codingwell.scalaguice

import com.google.inject.Binder
import com.google.inject.binder._
import com.google.inject.name.Names
import java.lang.annotation.{Annotation => JAnnotation}
import javax.inject.Provider

/**
 * Extensions for Guice's binding DSL.
 * These allow using a type parameter instead of <code>classOf[Foo]}</code>
 * or <code>new TypeLiteral[Bar[Foo]] {}</code>. The extra methods are
 * named as those in the normal binding DSL suffixed with <code>Type</code>.
 *
 * For example, instead of
 * {{{
 * binder.bind(new TypeLiteral[Bar[Foo]]{}).to(classOf[FooBarImpl])
 * }}}
 * use
 * {{{
 * import BindingExtensions._
 * binder.bindType[Bar[Foo]].toType[FooImpl]
 * }}}
 *
 * '''Note''' This syntax allows binding to and from generic types.
 * It doesn't currently allow bindings between wildcard types because the
 * manifests for wildcard types don't provide access to type bounds.
 */
object BindingExtensions {

  implicit class ScalaBinder(b: Binder) {
    def bindType[T: Manifest] = b bind typeLiteral[T]
  }

  implicit class ScalaScopedBindingBuilder(b: ScopedBindingBuilder) {
    def inType[TAnn <: JAnnotation : Manifest]() = b in cls[TAnn]
  }

  implicit class ScalaLinkedBindingBuilder[T](b: LinkedBindingBuilder[T]) {
    def toType[TImpl <: T : Manifest] = b to typeLiteral[TImpl]

    def toProviderType[TProvider <: Provider[_ <: T] : Manifest] = b toProvider cls[TProvider]
  }

  implicit class ScalaAnnotatedBindingBuilder[T](b: AnnotatedBindingBuilder[T]) {
    def annotatedWithType[TAnn <: JAnnotation : Manifest] = b annotatedWith cls[TAnn]
  }

  implicit class ScalaAnnotatedConstantBindingBuilder(b: AnnotatedConstantBindingBuilder) {
    def annotatedWithType[TAnn <: JAnnotation : Manifest] = b annotatedWith cls[TAnn]
    def annotatedWithName(name: String) = b annotatedWith Names.named(name)
  }

  implicit class ScalaConstantBindingBuilder(b: ConstantBindingBuilder) {
    def to[T: Manifest]() = b to cls[T]
  }
}

==> scala-guice_2.12-4.2.6-sources.jar: net/codingwell/scalaguice/BindingExtensions.scala <==
/*
 *  Copyright 2010-2014 Benjamin Lings
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.codingwell.scalaguice

import com.google.inject.Binder
import com.google.inject.binder._
import com.google.inject.name.Names
import java.lang.annotation.{Annotation => JAnnotation}
import scala.reflect.ClassTag
import scala.reflect.runtime.universe.TypeTag

import javax.inject.Provider

/**
 * Extensions for Guice's binding DSL.
 * These allow using a type parameter instead of <code>classOf[Foo]}</code>
 * or <code>new TypeLiteral[Bar[Foo]] {}</code>. The extra methods are
 * named as those in the normal binding DSL suffixed with <code>Type</code>.
 *
 * For example, instead of
 * {{{
 * binder.bind(new TypeLiteral[Bar[Foo]]{}).to(classOf[FooBarImpl])
 * }}}
 * use
 * {{{
 * import BindingExtensions._
 * binder.bindType[Bar[Foo]].toType[FooImpl]
 * }}}
 *
 * '''Note''' This syntax allows binding to and from generic types.
 * It doesn't currently allow bindings between wildcard types because the
 * manifests for wildcard types don't provide access to type bounds.
 */
object BindingExtensions {

  implicit class ScalaBinder(b: Binder) {
    def bindType[T: TypeTag]: AnnotatedBindingBuilder[T] = b bind typeLiteral[T]
  }

  implicit class ScalaScopedBindingBuilder(b: ScopedBindingBuilder) {
    def inType[TAnn <: JAnnotation : ClassTag]() = b in cls[TAnn]
  }

  implicit class ScalaLinkedBindingBuilder[T](b: LinkedBindingBuilder[T]) {
    def toType[TImpl <: T : TypeTag] = b to typeLiteral[TImpl]

    def toProviderType[TProvider <: Provider[_ <: T] : ClassTag] = b toProvider cls[TProvider]
  }

  implicit class ScalaAnnotatedBindingBuilder[T](b: AnnotatedBindingBuilder[T]) {
    def annotatedWithType[TAnn <: JAnnotation : ClassTag] = b annotatedWith cls[TAnn]
  }

  implicit class ScalaAnnotatedConstantBindingBuilder(b: AnnotatedConstantBindingBuilder) {
    def annotatedWithType[TAnn <: JAnnotation : ClassTag] = b annotatedWith cls[TAnn]
    def annotatedWithName(name: String) = b annotatedWith Names.named(name)
  }

  implicit class ScalaConstantBindingBuilder(b: ConstantBindingBuilder) {
    def to[T: ClassTag]() = b to cls[T]
  }
}
